@@ -55,10 +55,16 @@ class HumanReadableTextFormatting:
         if x == 0:
             return '0'
 
+        if x < 0:
+            sign = '-'
+            x = -x
+        else:
+            sign = ''
+
         units = ['', 'K', 'M', 'G', 'T', 'P']
         k = 1000.0
         magnitude = int(floor(log(x, k)))
-        return f'{round(x / k**magnitude)}{units[magnitude]}'
+        return f'{sign}{round(x / k**magnitude)}{units[magnitude]}'
 
     @staticmethod
     def html_text_augment(x, methods):
@@ -103,7 +109,7 @@ def distlr_fig_formatting(fig):
             '#05152D'
         ],
         'fig_width': 282,
-        'fig_height': 260,
+        'fig_height': 325,
         'axis_font_size': 10,
         'data_label_font_size': 12,
         'titlefont_size': 12
@@ -126,8 +132,7 @@ def format_fig_layout(fig, fig_params):
 
     # adjust fig height based on number of figures
     # .75 fig_height for every fig greater than 1
-    fig_height = fig_params['fig_height']
-    fig_height = n_rows * fig_height + (n_rows-1)*.5 * fig_height
+    fig_height = n_rows * fig_params['fig_height']
     fig_width = fig_params['fig_width']
 
     fig.update_layout(
@@ -143,7 +148,11 @@ def format_fig_layout(fig, fig_params):
         hovermode=False
     )
 
-    fig.update_annotations(font_size=fig_params['data_label_font_size'])
+    fig.update_annotations(
+        font_size=fig_params['data_label_font_size'],
+        # y=1.05, yanchor='bottom', yref='paper'
+    )
+
     fig.update_yaxes(
         showline=True,
         showgrid=True,
